<?php
/**
 * Display Menu Item Icon Walker
 *
 * @package   dorzki\WooCommerce\BOGO
 * @author    Dor Zuberi <admin@dorzki.io>
 * @copyright 2023 dorzki
 * @version   1.0.0
 */

namespace dorzki\WordPress\AddMenuIcon;

use stdClass;
use Walker_Nav_Menu;
use WP_Post;

// Block if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Class Display_Menu_Item_Icon_Walker
 *
 * @package dorzki\WordPress\AddMenuIcon
 */
class Display_Menu_Item_Icon_Walker extends Walker_Nav_Menu {
	/**
	 * Output the menu item on the front-end
	 *
	 * @param string        $output Used to append additional content (passed by reference)
	 * @param WP_Post       $data_object The data object
	 * @param int           $depth Depth of the item
	 * @param stdClass|null $args An array of additional arguments
	 * @param int           $current_object_id Optional, ID of the current item, Default 0
	 */
	public function start_el( &$output, $data_object, $depth = 0, $args = null, $current_object_id = 0 ) {
		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

		$value = '';

		$classes = empty( $data_object->classes ) ? array() : (array) $data_object->classes;

		$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $data_object ) );
		$class_names = ' class="' . esc_attr( $class_names ) . '"';

		$output .= $indent . '<li id="menu-item-' . $data_object->ID . '"' . $value . $class_names . '>';

		$attributes  = ! empty( $data_object->attr_title ) ? ' title="' . esc_attr( $data_object->attr_title ) . '"' : '';
		$attributes .= ! empty( $data_object->target ) ? ' target="' . esc_attr( $data_object->target ) . '"' : '';
		$attributes .= ! empty( $data_object->xfn ) ? ' rel="' . esc_attr( $data_object->xfn ) . '"' : '';
		$attributes .= ! empty( $data_object->url ) ? ' href="' . esc_attr( $data_object->url ) . '"' : '';

		$prepend     = '<span>';
		$append      = '</span>';
		$description = ! empty( $data_object->description ) ? '<span>' . esc_attr( $data_object->description ) . '</span>' : '';

		if ( 0 !== $depth ) {
			$description = '';
			$append      = '';
			$prepend     = '';
		}

		$item_output  = $args->before;
		$item_output .= '<a' . $attributes . '><span aria-hidden="true" class="' . $data_object->link_icon . '"></span>';
		$item_output .= $args->link_before . $prepend . apply_filters( 'the_title', $data_object->title, $data_object->ID ) . $append;
		$item_output .= $description . $args->link_after;
		$item_output .= '</a>';
		$item_output .= $args->after;

		$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $data_object, $depth, $args );
	}
}
