<?php
/**
 * Edit Menu Item Icon Walker
 *
 * @package   dorzki\WooCommerce\BOGO
 * @author    Dor Zuberi <admin@dorzki.io>
 * @copyright 2023 dorzki
 * @version   1.0.0
 */

namespace dorzki\WordPress\AddMenuIcon;

use stdClass;
use Walker_Nav_Menu_Edit;
use WP_Post;

// Block if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Class Edit_Menu_Item_Icon_Walker
 *
 * @package dorzki\WordPress\AddMenuIcon
 */
class Edit_Menu_Item_Icon_Walker extends Walker_Nav_Menu_Edit {
	/**
	 * Output the item form.
	 *
	 * @param string        $output Used to append additional content (passed by reference)
	 * @param WP_Post       $data_object Menu item data object
	 * @param int           $depth Depth of menu item, Used for padding
	 * @param stdClass|null $args Not used
	 * @param int           $current_object_id Optional ID, of the current menu item, Default 0
	 */
	public function start_el( &$output, $data_object, $depth = 0, $args = null, $current_object_id = 0 ) {
		$item_output = '';

		parent::start_el( $item_output, $data_object, $depth, $args );

		$new_fields = apply_filters( 'menu_edit_add_fields', '', $item_output, $data_object, $depth, $args );

		if ( ! empty( $new_fields ) ) {
			$item_output = preg_replace( '/(?=<div[^>]+class="[^"]*submitbox)/', $new_fields, $item_output );
		}

		$output .= $item_output;
	}
}
