<?php
/**
 * Main Plugin
 *
 * @package   dorzki\WooCommerce\BOGO
 * @author    Dor Zuberi <admin@dorzki.io>
 * @copyright 2023 dorzki
 * @version   1.0.0
 */

namespace dorzki\WordPress\AddMenuIcon;

use WP_Post;

// Block if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Class Plugin
 *
 * @package dorzki\WordPress\AddMenuIcon
 */
class Plugin {
	/** @var array */
	protected array $icons = array();


	/**
	 * Plugin constructor
	 */
	public function __construct() {
		$this->icons = [
			'li_heart'      => __( 'Heart', 'dorzki-add-menu-icon' ),
			'li_cloud'      => __( 'Cloud', 'dorzki-add-menu-icon' ),
			'li_star'       => __( 'Star', 'dorzki-add-menu-icon' ),
			'li_tv'         => __( 'TV', 'dorzki-add-menu-icon' ),
			'li_sound'      => __( 'Sound', 'dorzki-add-menu-icon' ),
			'li_video'      => __( 'Video', 'dorzki-add-menu-icon' ),
			'li_trash'      => __( 'Trash', 'dorzki-add-menu-icon' ),
			'li_user'       => __( 'User', 'dorzki-add-menu-icon' ),
			'li_key'        => __( 'Key', 'dorzki-add-menu-icon' ),
			'li_search'     => __( 'Search', 'dorzki-add-menu-icon' ),
			'li_settings'   => __( 'Cog', 'dorzki-add-menu-icon' ),
			'li_camera'     => __( 'Camera', 'dorzki-add-menu-icon' ),
			'li_tag'        => __( 'Tag', 'dorzki-add-menu-icon' ),
			'li_lock'       => __( 'Lock', 'dorzki-add-menu-icon' ),
			'li_bulb'       => __( 'Light-bulb', 'dorzki-add-menu-icon' ),
			'li_pen'        => __( 'Pen', 'dorzki-add-menu-icon' ),
			'li_diamond'    => __( 'Diamond', 'dorzki-add-menu-icon' ),
			'li_display'    => __( 'Display', 'dorzki-add-menu-icon' ),
			'li_location'   => __( 'Location', 'dorzki-add-menu-icon' ),
			'li_eye'        => __( 'Eye', 'dorzki-add-menu-icon' ),
			'li_bubble'     => __( 'Bubble', 'dorzki-add-menu-icon' ),
			'li_stack'      => __( 'Chat', 'dorzki-add-menu-icon' ),
			'li_cup'        => __( 'Cup', 'dorzki-add-menu-icon' ),
			'li_phone'      => __( 'Phone', 'dorzki-add-menu-icon' ),
			'li_news'       => __( 'News', 'dorzki-add-menu-icon' ),
			'li_mail'       => __( 'Mail', 'dorzki-add-menu-icon' ),
			'li_like'       => __( 'Like', 'dorzki-add-menu-icon' ),
			'li_photo'      => __( 'Photo', 'dorzki-add-menu-icon' ),
			'li_note'       => __( 'Note', 'dorzki-add-menu-icon' ),
			'li_clock'      => __( 'Clock', 'dorzki-add-menu-icon' ),
			'li_paperplane' => __( 'Paper-plane', 'dorzki-add-menu-icon' ),
			'li_params'     => __( 'Params', 'dorzki-add-menu-icon' ),
			'li_banknote'   => __( 'Banknote', 'dorzki-add-menu-icon' ),
			'li_data'       => __( 'Data', 'dorzki-add-menu-icon' ),
			'li_music'      => __( 'Music', 'dorzki-add-menu-icon' ),
			'li_megaphone'  => __( 'Megaphone', 'dorzki-add-menu-icon' ),
			'li_study'      => __( 'Study', 'dorzki-add-menu-icon' ),
			'li_lab'        => __( 'Lab', 'dorzki-add-menu-icon' ),
			'li_food'       => __( 'Food', 'dorzki-add-menu-icon' ),
			'li_t-shirt'    => __( 'T-Shirt', 'dorzki-add-menu-icon' ),
			'li_fire'       => __( 'Fire', 'dorzki-add-menu-icon' ),
			'li_clip'       => __( 'Clip', 'dorzki-add-menu-icon' ),
			'li_shop'       => __( 'Shop', 'dorzki-add-menu-icon' ),
			'li_calendar'   => __( 'Calendar', 'dorzki-add-menu-icon' ),
			'li_wallet'     => __( 'Wallet', 'dorzki-add-menu-icon' ),
			'li_vinyl'      => __( 'Vinyl', 'dorzki-add-menu-icon' ),
			'li_truck'      => __( 'Truck', 'dorzki-add-menu-icon' ),
			'li_world'      => __( 'World', 'dorzki-add-menu-icon' ),
		];

		add_action( 'wp_setup_nav_menu_item', [ $this, 'retrieve_menu_icon_field' ] );
		add_action( 'wp_update_nav_menu_item', [ $this, 'save_menu_icon_field' ], 10, 2 );
		add_action( 'wp_edit_nav_menu_walker', [ $this, 'register_menu_edit_walker' ] );
		add_action( 'wp_nav_menu_args', [ $this, 'register_menu_display_walker' ], 10, 2 );
		add_action( 'wp_enqueue_scripts', [ $this, 'register_plugin_assets' ] );
		add_action( 'plugins_loaded', [ $this, 'register_plugin_i18n' ] );

		add_filter( 'menu_edit_add_fields', [ $this, 'add_menu_icon_field' ], 10, 3 );
	}


	/**
	 * Retrieves the menu icon field from the database
	 *
	 * @param object $menu_item the menu item object
	 *
	 * @return object
	 */
	public function retrieve_menu_icon_field( object $menu_item ): object {
		$menu_icon = get_post_meta( $menu_item->ID, '_menu_link_icon', true );

		$menu_item->link_icon = ( ! empty( $menu_icon ) ) ? $menu_icon : '';

		return $menu_item;
	}

	/**
	 * Saves the menu icon field to database
	 *
	 * @param integer $menu_id Menu id number
	 * @param integer $menu_item_id Menu item id number
	 */
	public function save_menu_icon_field( int $menu_id, int $menu_item_id ) {
		$menu_icon = ! empty($_REQUEST['menu-item-icon']) ? $_REQUEST['menu-item-icon'][ $menu_item_id ] : null; // phpcs:ignore

		if ( $menu_icon ) {
			$link_icon = $menu_icon;

			update_post_meta( $menu_item_id, '_menu_link_icon', $link_icon );
		}
	}

	/**
	 * Registers the menu edit screen walker
	 *
	 * @return string
	 */
	public function register_menu_edit_walker(): string {
		return '\dorzki\WordPress\AddMenuIcon\Edit_Menu_Item_Icon_Walker';
	}

	/**
	 * Registers the menu display (front-end) walker
	 *
	 * @param array $args Menu args
	 *
	 * @return array
	 */
	public function register_menu_display_walker( array $args ): array {
		if ( empty( $args['walker'] ) ) {
			$args['walker'] = new Display_Menu_Item_Icon_Walker();
		}

		return $args;
	}

	/**
	 * Register plugin assets so we can display the icons
	 */
	public function register_plugin_assets() {
		wp_enqueue_style(
			'linecons-webfont',
			DRZK_MENU_ICON_URL . 'assets/css/style.css',
			[],
			'1.0.0'
		);
	}

	/**
	 * Add support for I18n
	 */
	public function register_plugin_i18n() {
		load_plugin_textdomain( 'dorzki-add-menu-icon' );
	}

	/**
	 * Add the field to the menu edit screen
	 *
	 * @param string  $new_fields template of new fields
	 * @param string  $item_output the menu item HTML output
	 * @param WP_Post $item the menu item data
	 *
	 * @return string
	 */
	public function add_menu_icon_field( string $new_fields, string $item_output, WP_Post $item ): string {
		$current_value = get_post_meta( $item->ID, '_menu_link_icon', true );

		$new_fields .= '<p class="additional-menu-field-icon description description-thin">';
		$new_fields .= '  <label for="edit-menu-item-icon-' . $item->ID . '">' . __( 'Icon', 'dorzki-add-menu-icon' ) . '<br>';
		$new_fields .= '    <select id="edit-menu-item-icon-' . $item->ID . '" class="widefat code edit-menu-item-icon" name="menu-item-icon[' . $item->ID . ']">';

		foreach ( $this->icons as $class => $name ) {
			$new_fields .= '      <option value="' . $class . '" ' . selected( $current_value, $class, false ) . '>' . $name . '</option>';
		}

		$new_fields .= '    </select>';
		$new_fields .= '  </label>';
		$new_fields .= '</p>';

		return $new_fields;
	}
}

// Init class.
new Plugin();
